@@ -21,7 +21,7 @@ class ProcessPipes:
     stdin: Any
 
 
-class OutputType(enum.Enum):
+class ProcessOutputType(enum.Enum):
     """-"""
     DEBUG = 0
     STDOUT = 1
@@ -31,24 +31,27 @@ class OutputType(enum.Enum):
         return str(self.name)
 
 
-async def readline(pipe: Any) -> Tuple[OutputType, Optional[str]]:
-    """-"""
+async def readline(pipe: Any) -> Tuple[ProcessOutputType, Optional[str]]:
+    """Reads line from pipe and returns it together with
+    the output type STDOUT|STDERR|DEBUG.
+    Returns EOFError when pipe has reached the end/is closed.
+    """
 
     data = await pipe.readline()
     if data:
-        line = str(data.decode('ascii').rstrip())
+        line = str(data.decode('utf-8').rstrip())
         if line.strip().startswith("INFO "):
             line = line.replace("INFO ", "")
-            return (OutputType.STDOUT, line)
+            return (ProcessOutputType.STDOUT, line)
         elif line.strip().startswith("ERROR "):
             line = line.replace("ERROR ", "")
-            return (OutputType.STDERR, line)
+            return (ProcessOutputType.STDERR, line)
         else:
             if line.strip().startswith("DEBUG "):
                 line = line.replace("DEBUG ", "")
-            return (OutputType.DEBUG, line)
+            return (ProcessOutputType.DEBUG, line)
 
-    return (OutputType.DEBUG, None)
+    raise EOFError()
 
 
 def make_puid(pid: int, create_timestamp: int) -> str:
